#!/bin/sh
# $Id: t-ibdb-0.sh,v 1.5 2011/02/01 06:02:45 ca Exp $
# Copyright (c) 2010 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# test IBDB handling: write/read all necessary data
# uses mcpmts.sh
# ----------------------------------------
#

SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../chkmts
fi
. ${SD}/common.sh

OUT="t-ibdb-0.out"

if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

# cd to right directory (where the programs will be executed).
cd ../qmgr || exit 1

COMMERCIAL=false
./qmgr -VVV > ${OUT}
${GREP} COMMERCIAL ${OUT} >/dev/null && \
  ${GREP} SMI_MAILEXT ${OUT} >/dev/null && \
    ${GREP} SMI_PRI ${OUT} >/dev/null && \
      COMMERCIAL=true
if ${COMMERCIAL}
then
 AO='-d 0 -M RMAX=120_QRET=360_IID=SomeID_PRI=1'
else
 AO='-d 0'
fi

rm -f ${MTMAP}

# create directory to pass socket
test -d smtps || mkdir smtps

killit()
{
rm -f ${QMGRCONFMAP} ${MTMAP}
exit 1
}

# currently no map data needed/used
${CAT} > ${QMGRCONF} <<EOF
EOF
# create map
rm -f ${QMGRCONFMAP}
${MM} -t'	' -F ${QMGRCONFMAP} < ${QMGRCONF}
rm -f ${MTMAP}
trap killit 2

# ----------------------------------------
# no smtpc
${CAT} >${SMXCNF} <<EOF
smtps { log_level = 14; pass_fd_socket = smtps/smtpsfd; wait_for_server=4;
	listen_socket { type=inet; port=${SRVPORT}; }
	start_action = pass; user = ${USER};
	path = ../smtps/smtps;
	arguments = "smtps -f ${SMXCNF} ${MTA_SERVER_OPTIONS}";
}
qmgr { log_level = 14; wait_for_server=4; wait_for_client=4; 
	start_action = wait; user = ${USER};
    retry_delay_min = 1s;
	path = "../qmgr/qmgr"; arguments = "qmgr -f ${SMXCNF}";
}
smar { log_level = 14;
	start_action = wait; user = ${USER};
	path = "../smar/smar"; arguments = "smar -f ${SMXCNF}";
}
EOF

${CAT} > ${MT} <<EOF
b.c	[10.2.1.1]
dom1.tld	[10.1.1.1]
EOF

clearlogs

chkibdb()
{
  if grep "$@" ${OUT} >/dev/null
  then
    :
  else
    ERR=true
  fi
}

chknibdb()
{
  if grep "$@" ${OUT} >/dev/null
  then
    ERR=true
  fi
}

chkc()
{
  if grep "$@" smtpc.log >/dev/null
  then
    :
  else
    ERR=true
  fi
}

# ----------------------------------------
# no smtpc: mail will get stuck
TEST=1
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
ERR=false
# 
if ${SHELL} ${SD}/mcpmts.sh -C -s 1 -1 -A 1 -E 0 -X 0 -Zsmtpc2 -S"a0@b.c" -R"r0@dom1.tld" -c "${AO}"
then
  ${IDBR0} -VVVVV > ${OUT}
  chkibdb 'MAIL: OPEN:.* mail_pa=<a0@b.c>'
  chkibdb 'RCPT: OPEN: .* rcpt_pa=<r0@dom1.tld>'
  if ${COMMERCIAL}
  then
    chkibdb "IID=SomeID"
    chkibdb "pri=1"
    chkibdb "rmax=7200"
    chkibdb "queueret=21600"
  fi
else
  ERR=true
fi
if $ERR
then
  :
else
# ----------------------------------------
${CAT} >${SMXCNF} <<EOF
smtps { log_level = 14; pass_fd_socket = smtps/smtpsfd; wait_for_server=4;
	listen_socket { type=inet; port=${SRVPORT}; }
	start_action = pass; user = ${USER};
	path = ../smtps/smtps;
	arguments = "smtps -f ${SMXCNF} ${MTA_SERVER_OPTIONS}";
}
smtpc { log_level = 14; remote_port = ${SNKPORT}; wait_for_server=4;
	connect_only_to = 127.0.0.1;
	io_timeout=60s;
	start_action = wait; user = ${USER};
	path = "../smtpc/smtpc"; arguments = "smtpc -f ${SMXCNF}";
}
qmgr { log_level = 14; wait_for_server=4; wait_for_client=4; 
	start_action = wait; user = ${USER};
	path = "../qmgr/qmgr"; arguments = "qmgr -f ${SMXCNF}";
}
smar { log_level = 14;
	start_action = wait; user = ${USER};
	path = "../smar/smar"; arguments = "smar -f ${SMXCNF}";
}
EOF

if ${SHELL} ${SD}/mcpmts.sh -D -I -1 -A 1 -E 2 -X 1 -Zsmtpc2 -S"a1@b.c" -R"r1@dom1.tld"
then
  ${IDBR0} -VVVVV > ${OUT}
  chknibdb 'MAIL: OPEN:.* mail_pa=<a0@b.c>'
  chknibdb 'RCPT: OPEN: .* rcpt_pa=<r0@dom1.tld>'
  chkc a0@b.c
  chkc r0@dom1.tld
  chkc a1@b.c
  chkc r1@dom1.tld
  if ${COMMERCIAL}
  then
    chkc 'rcpt=<r0@dom1.tld>, iid=SomeID'
  fi
else
  ERR=true
fi

fi

if ${ERR}
then
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
else
  ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi

rm -f ${QMGRCONFMAP} ${MTMAP}


# ----------------------------------------
# end
if test ${ERRS} -eq 0
then
  # rm -f ${OUT}
  exit 0
else
  echo "$0: ${ERRS} error(s)"
  exit 1
fi
