/*
 * Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 *
 * $Id: scdef.h,v 1.19 2013/12/28 04:22:50 ca Exp $
 */

#ifndef SM_SCDEF_H
#define SM_SCDEF_H 1

#include "sm/generic.h"
#include "sm/units.h"

#define SMTPC_PORT 25	/* default port to use */

/* Default SMTPC Id */
#define SMTPC_ID	1

/*
**  RFC 2821:
**     Initial 220 Message: 5 minutes
**     MAIL Command: 5 minutes
**     RCPT Command: 5 minutes
**     DATA Initiation: 2 minutes
**     Data Block: 3 minutes
**     DATA Termination: 10 minutes.
**  The value below is the minimum of all of these.
**  It seems we need different values according to RFC 2821.
*/

#define SC_IO_TIMEOUT 120	/* I/O with SMTP server */

/* timeout to send an RCB to QMGR */
#ifndef SC_RCB_SND_TMO
#define SC_RCB_SND_TMO	30
#endif

/* Max number of "spare" threads per process per socket */
#define WAIT_THREADS_DEFAULT_MAX 8

/* Min number of "spare" threads per process per socket */
#define WAIT_THREADS_DEFAULT_MIN 2

/* Max number of threads per process per socket */
#define THREADS_DEFAULT_MAX 0	/* determined by system */

/* see smtpc/smtpc.h! SCC_CFL_ */
#define SCC_CFL_NOTTM		0x00000002 /* don't check "talk to myself" */
#define SCC_CFL_STARTTLS	0x00000004

/* free: 0x00000010 * was: run in background mode */
#define SCC_CFL_READ_QUIT	0x00000020 /* read reply for QUIT command */

/*
**  (try to) send final dot and QUIT in different TCP packets
**  even if PIPELINING is offered.
*/
#define SCC_CFL_SEP_DOT_QUIT	0x00000040
#define SCC_CFL_SEP_STATS_TM	0x00000080	/* accurate timing statistics */
#define SCC_CFL_RSET	0x00000100	/* use RSET between TAs */
#define SCC_CFL_ALTEV	0x00000200	/* use alternate event system */

/* mask for "inheriting" sc_cnf_cflags (conf -> session); use SCC_CFL|...? */
#define SCC_CFL_INHMASK		0x00000187

/* SMTPC session flags */
/* convert SCC_ flag to SCSE flag: */
/* :'a,.s/SCC_\(.*\)/SCSE_\1	&/ */
#define SCSE_CFL_NOTTM		SCC_CFL_NOTTM
#define SCSE_CFL_STARTTLS	SCC_CFL_STARTTLS
#define SCSE_CFL_READ_QUIT	SCC_CFL_READ_QUIT
#define SCSE_CFL_SEP_DOT_QUIT	SCC_CFL_SEP_DOT_QUIT
#define SCSE_CFL_SEP_STATS_TM	SCC_CFL_SEP_STATS_TM
#define SCSE_CFL_RSET	SCC_CFL_RSET

/* mask for "inheriting" feature flags (feature -> session) */
#define SCSE_CFL_INHERIT	(SCC_CFL_NOTTM|SCC_CFL_STARTTLS|SCC_CFL_READ_QUIT|SCC_CFL_SEP_DOT_QUIT|SCC_CFL_SEP_STATS_TM|SCC_CFL_RSET)

#if SC_TEST
#define SCC_CNF_TEST_DUMMY		0x00000001
#define SCC_CNF_TEST_BODY_TMO	0x00000002
#endif
#define SCC_CNF_CLIENT_BIND	0x00000040	/* ??? collision??? */

#endif /* SM_SCDEF_H */
