/*
 * Copyright (c) 2010 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: base64encode.c,v 1.4 2011/01/09 05:55:45 ca Exp $")

#include "sm/assert.h"
#include "sm/error.h"
#include "sm/str.h"
#include "sm/str-int.h"
#include "sm/base64.h"

/* base64 alphabet */
static unsigned char alphabet[64] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

/*
**  SM_B64_ENCODE -- encode base64 data
**
**  Parameters:
**  	in -- data to encode
**  	out -- where to write the encoding
**
**  Return value:
*/

#define SMPUTCH(out, ch) do {			\
		ret = SM_STR_PUT((out), (ch));	\
		if (sm_is_err(ret))		\
			goto error;		\
	} while (0)

sm_ret_T
sm_b64_encode(sm_str_P in, sm_str_P out)
{
	sm_ret_T ret;
	int bits, c, char_count;

	SM_IS_BUF(in);
	SM_IS_BUF(out);
	bits = char_count = 0;
	for (c = 0; c < sm_str_getlen(in); c++) {
		bits += sm_str_rd_elem(in, c);
		char_count++;
		if (char_count == 3) {
			SMPUTCH(out, alphabet[bits >> 18]);
			SMPUTCH(out, alphabet[(bits >> 12) & 0x3f]);
			SMPUTCH(out, alphabet[(bits >> 6) & 0x3f]);
			SMPUTCH(out, alphabet[bits & 0x3f]);
			bits = 0;
			char_count = 0;
		}
		else
			bits <<= 8;
	}

	if (char_count != 0) {
		bits <<= 16 - (8 * char_count);
		SMPUTCH(out, alphabet[bits >> 18]);
		SMPUTCH(out, alphabet[(bits >> 12) & 0x3f]);
		if (char_count == 1) {
			SMPUTCH(out, '=');
			SMPUTCH(out, '=');
		}
		else {
			SMPUTCH(out, alphabet[(bits >> 6) & 0x3f]);
			SMPUTCH(out, '=');
		}
	}
	return SM_SUCCESS;

  error:
	return ret;
}
