/*
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: spec2sock.c,v 1.3 2010/10/03 03:18:02 ca Exp $")

#include "sm/assert.h"
#include "sm/error.h"
#include "sm/memops.h"
#include "sm/socket.h"
#include "sm/sockcnf.h"

/*
**  SOCKSPEC2SOCK -- convert sockspec to sockaddr
**
**	Parameters:
**		sockspec -- socket specification
**		sockaddr -- pointer to sockaddr (output)
**		sock_size -- pointer to socket size (output)
**		flags -- flags
**
**	Returns:
**		usual return code
*/

sm_ret_T
sockspec2sock(sockspec_P sockspec, sm_sockaddr_P sm_sockaddr, sockaddr_len_T *psock_size, uint flags)
{
	SM_REQUIRE(sockspec != NULL);
	SM_REQUIRE(sm_sockaddr != NULL);
	SM_REQUIRE(psock_size != NULL);

	sm_memset(sm_sockaddr, 0, sizeof(*sm_sockaddr));
	switch (sockspec->sckspc_type) {
	  case SOCK_TYPE_INET:
		sm_sockaddr->sin.sin_family = AF_INET;
		sm_sockaddr->sin.sin_addr.s_addr = sockspec->sock_inet.inetsckspc_addr;
		sm_sockaddr->sin.sin_port = sockspec->sock_inet.inetsckspc_port;
		*psock_size = sizeof(sm_sockaddr->sin);
		break;

#if MTA_NETINET6
	  case SOCK_TYPE_INET6:
		sm_sockaddr->sin6.sin6_family = AF_INET6;
		IPV6_ASSIGN(&sm_sockaddr->sin6.sin6_addr.s6_addr,
				&sockspec->sock_inet6.inet6sckspc_addr);
		sm_sockaddr->sin6.sin6_port = sockspec->sock_inet6.inet6sckspc_port;
		*psock_size = sizeof(sm_sockaddr->sin6);
		break;
#endif

	  case SOCK_TYPE_UNIX:
		{
		size_t len;

		sm_sockaddr->sunix.sun_family = AF_UNIX;
		len = strlcpy(sm_sockaddr->sunix.sun_path,
			sockspec->sock_unix.unixsckspc_path,
			sizeof(sm_sockaddr->sunix.sun_path));
		if (len <= 0 || len >= sizeof(sm_sockaddr->sunix.sun_path))
			return sm_error_perm(SM_EM_STTHRIO, SM_E_2BIG);
#if HAVE_SOCK_UN_SUN_LEN
		sm_sockaddr->sunix.sun_len =
				strlen(sockspec->sock_unix.unixsckspc_path);
#endif
		if (SM_IS_FLAG(SS2S_FL_RMUNIX, flags)) {
			/* unlink socket (might not exist) */
			(void) unlink(sockspec->sock_unix.unixsckspc_path);
		}

		*psock_size = sizeof(sm_sockaddr->sunix);
		break;
		}
	  default:
		return sm_error_perm(SM_EM_STTHRIO, EINVAL);
	}

	return SM_SUCCESS;
}
