/*
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: t-xtextchk.c,v 1.2 2008/11/04 04:33:08 ca Exp $")
#include "sm/assert.h"
#include "sm/error.h"
#include "sm/str.h"
#include "sm/misc.h"
#include "sm/io.h"
#include "sm/test.h"

static int Verbosity = 0;

#define LEN	256

static void
test(char *xtext)
{
	bool ok;
	uint i;
	sm_str_P str;
	char *d;
	char *xtextok[] = {
		"a", "+AB", "A+CB", "A+EF", "",
		"+ab.c", "abc+d0",
		"0123456789", "abcdefghijklmnopqrstuvwxyz",
		"0123456789abcdefghijklmnopqrstuvwxyz",
		"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",
		NULL };
	char *xtextfail[] = { "+", "+1", "+1+", "+++", "A+B",
		NULL };


	str = sm_str_new(NULL, LEN, LEN + 2 );
	SM_TEST(str != NULL);
	if (str == NULL)
		return;

	sm_str_clr(str);
	if (xtext != NULL) {
		sm_str_scat(str, xtext);
		ok = validxtext(str);
		SM_TEST(ok);
		goto done;
	}

	for (i = 0; (d = xtextok[i]) != NULL; i++) {
		sm_str_clr(str);
		sm_str_scat(str, d);
		ok = validxtext(str);
		SM_TEST(ok);
		if (!ok)
			sm_io_fprintf(smioerr, "xtext=%s\n", d);
	}

	for (i = 0; (d = xtextfail[i]) != NULL; i++) {
		sm_str_clr(str);
		sm_str_scat(str, d);
		ok = validxtext(str);
		SM_TEST(!ok);
		if (ok)
			sm_io_fprintf(smioerr, "xtext=%s\n", d);
	}

	for (i = 1; i < '!'; i++) {
		sm_str_clr(str);
		SM_STR_PUT(str, (uchar) i);
		ok = validxtext(str);
		SM_TEST(!ok);
		if (ok)
			sm_io_fprintf(smioerr, "xtext=%s\n", d);
	}

	for (i = '~' + 1; i < 255; i++) {
		sm_str_clr(str);
		SM_STR_PUT(str, (uchar) i);
		ok = validxtext(str);
		SM_TEST(!ok);
		if (ok)
			sm_io_fprintf(smioerr, "xtext=%s\n", d);
	}

  done:
	sm_str_free(str);
	return;
}

int
main(int argc, char *argv[])
{
	int c;

	while ((c = getopt(argc, argv, "V")) != -1) {
		switch (c) {
		  case 'V':
			++Verbosity;
			break;
		}
	}
	sm_test_begin(argc, argv, "test xtextok");

	argc -= optind;
	argv += optind;

	if (argc > 0) {
		for (c = 0; c < argc; c++)
			test(argv[c]);
	}
	else
		test(NULL);

	return sm_test_end();
}
