#!/bin/sh
# $Id: t-mt-0.sh,v 1.29 2013/11/19 04:59:17 ca Exp $
# Copyright (c) 2004, 2005 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ------------------------------------------------------------
# Description:
# simple mailertable routing tests by contacting SMAR
# uses t-smar-1 and startsmar.sh
# ------------------------------------------------------------
#

# path to programs
P=..
TPRG=./t-smar-1
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${SOCK} ${PIDS}

# prepare mailertable
# note: bogus.org has trailing space
${CAT} > ${MT} <<EOF
host123.meta1.org	[1.2.3.0]
MiXeD.meta1.org	[1.2.3.9]
meta1.org	[1.2.3.2]
.meta1.org	[1.2.3.4]
.org		[1.2.3.6]
.		[1.2.3.9]
bogus.org	[1.0.0.64] 
blank2.org	[1.0.0.65]    [1.0.0.66]     
local.dom	lmtp:
EOF

HAS_MTA_NETINET6=false
if ${TPRG} -C | grep MTA_NETINET6 >/dev/null
then
  HAS_MTA_NETINET6=true
${CAT} >> ${MT} <<EOF
ipv6.meta1.org	[0:0:0:0:0:0:0:1]
ipv6.short.org	[::1]
EOF
fi

# start SMAR
${SHELL} ${SD}/startsmar.sh ${SMAROPTS} || exit 1

rm -f ${OUT} ${IP} ${OK}

TEST=1
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@host123.meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.2.3.0 [1020300]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=2
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@host124.meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.2.3.4 [1020304]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=3
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.2.3.2 [1020302]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=4
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@metaX.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.2.3.6 [1020306]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=5
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@meta1.com>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.2.3.9 [1020309]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=6
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@bogus.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.0.0.64 [1000040]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=7
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@blank2.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=1.0.0.65 [1000041]
IP[1]=1.0.0.66 [1000042]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

TEST=8
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<local@local.dom>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=${MTA_LMTPIPV4D} [${MTA_LMTPIPV4H}]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi

# hmm, do I really want this? see smar/mtinit.c: hn[i++] = (uchar) c;
# TEST=9
# if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
# then
# # ----------------------------------------
# ${VALGRIND} ${TPRG} -M -VVVV '<a@MiXeD.meta1.org>' > ${OUT} 2>&1
# grep '^IP' ${OUT} | sort > ${IP}
# cat > ${OK} <<EOF
# IP[0]=1.2.3.9 [1020309]
# EOF
# if diff ${OK} ${IP}
# then
#   :
# else
#   ERRS=`expr ${ERRS} + 1 `
#   echo "$0: test ${TEST} failed."
#   test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
# fi
# fi


if ${HAS_MTA_NETINET6}
then
TEST=`expr ${TEST} + 1`
for ADDR in meta1 short
do
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV "<local@ipv6.${ADDR}.org>" > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=0:0:0:0:0:0:0:1 [0]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi
fi
done
fi

rm -f ${OUT} ${IP} ${OK}


# stop SMAR
for i in `cat ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi

test ${ERRS} -eq 0 && rm -f ${OUT} ${IP} ${OK}

exit ${ERRS}
